import { JSXElement, Show, createSignal, useContext } from "solid-js";

import { LoginContext, ModalContext } from "../Context/GlobalState";
import { AuthResponse, submitRegistration } from "../Util/api";

export function RegisterForm(): JSXElement {
  const modal_ctx = useContext(ModalContext)!;
  const login_ctx = useContext(LoginContext)!;
  const [username, setUsername] = createSignal<string>("");
  const [password, setPassword] = createSignal<string>("");
  const [captcha, setCaptcha] = createSignal<string>("");
  const [waiting, setWaiting] = createSignal(false);
  const [error, setError] = createSignal(false);

  async function loginFailed(): Promise<void> {
    setError(true);
    setWaiting(false);
    setTimeout(() => {
      setError(false);
    }, 1000);
  }

  const clearFields = (): void => {
    setUsername("");
    setPassword("");
    setCaptcha("");
  };

  const success = (response: AuthResponse): void => {
    setWaiting(false);
    setError(false);
    clearFields();
    login_ctx.logIn(response.username, response.token);
    modal_ctx.setOpen(false);
  };

  async function regPress(e: Event): Promise<void> {
    e.preventDefault();
    setWaiting(true);
    const data = await submitRegistration(username(), password(), captcha());
    if (data) success(data as AuthResponse);
    else loginFailed();
  }

  return (
    <form class="form-control space-y-2">
      <input
        type="text"
        placeholder="Username"
        value={username()}
        class="input input-bordered"
        onChange={(e): void => {
          setUsername(e.target.value);
        }}
      />

      <input
        type="password"
        placeholder="Password"
        value={password()}
        class="input input-bordered"
        onChange={(e): void => {
          setPassword(e.target.value);
        }}
      />

      <input
        type="text"
        placeholder="Captcha"
        value={captcha()}
        class="input input-bordered"
        onChange={(e): void => {
          setCaptcha(e.target.value);
        }}
      />

      <button
        classList={{ "btn btn-primary": !error(), "btn btn-error": error() }}
        onClick={regPress}
      >
        <Show when={waiting()} fallback="Register">
          Registering...
        </Show>
      </button>
    </form>
  );
}
