use serde::{Deserialize, Serialize};

/// The comment as it is received from the client
#[derive(Debug, Serialize, Deserialize)]
pub struct NewComment {
    pub parent_post_id: i64,
    pub parent_comment_id: Option<i64>,
    pub user_token: String,
    pub content: String,
}

/// The comment as it is stored in the database, with all the related metadata
#[derive(Debug, Serialize, Deserialize, Clone, sqlx::FromRow)]
pub struct Comment {
    pub id: i64,
    pub parent_post_id: i64,
    pub parent_comment_id: Option<i64>,
    pub author_user_id: i64,
    pub upvotes: i32,
    pub downvotes: i32,
    pub content: String,
    pub created_at: chrono::NaiveDateTime,
    pub updated_at: chrono::NaiveDateTime,
}

/// This is the comment as it is sent to the client, with only the public metadata
#[derive(Debug, Serialize, Deserialize, Clone, sqlx::FromRow)]
pub struct PublicComment {
    pub id: i64,
    pub parent_post_id: i64,
    pub upvotes: i32,
    pub downvotes: i32,
    pub content: String,
    pub created_at: chrono::NaiveDateTime,
    pub updated_at: chrono::NaiveDateTime,
}

/// Query parameters for the /comments endpoint
#[derive(Debug, Serialize, Deserialize)]
pub struct CommentQueryParams {
    pub post_id: i64,
    pub limit: Option<i64>,
    pub offset: Option<i64>,
}
