use serde::{Deserialize, Serialize};
use sqlx::FromRow;

// The post as it is received from the client
// The token is used to identify the user
#[derive(Debug, Serialize, Deserialize)]
pub struct NewPost {
    pub content: String,
    pub token: String,
}

// The post as it is stored in the database, with all the related metadata
#[derive(Debug, Serialize, Deserialize, Clone, FromRow)]
pub struct Post {
    pub id: i64,
    pub user_id: i64,
    pub content: String,
    pub upvotes: i64,
    pub downvotes: i64,
    pub created_at: chrono::NaiveDateTime,
    pub updated_at: chrono::NaiveDateTime,
}

// The post as it is sent to the client, with only the public metadata
#[derive(Debug, Serialize, Deserialize, Clone, FromRow)]
pub struct PublicPost {
    pub id: i64,
    pub content: String,
    pub upvotes: i64,
    pub downvotes: i64,
    pub created_at: chrono::NaiveDateTime,
    pub updated_at: chrono::NaiveDateTime,
}

// These look like /posts?limit=10&offset=20 in the URL
// Note that these are optional
/// Query parameters for the /posts endpoint
#[derive(Debug, Serialize, Deserialize)]
pub struct PostQueryParams {
    pub limit: Option<i64>,
    pub offset: Option<i64>,
}
